#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP0InBra_aB_d__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp177;
fp177 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp176;
fp176 = fp177 * src4[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp179;
fp179 = inteval->WP_z[vi] * src1[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp180;
fp180 = inteval->PA_z[vi] * src0[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp178;
fp178 = fp180 + fp179;
LIBINT2_REALTYPE fp175;
fp175 = fp178 + fp176;
target[((hsi*60+29)*1+lsi)*1] = fp175;
LIBINT2_REALTYPE fp183;
fp183 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp182;
fp182 = fp183 * src4[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp185;
fp185 = inteval->WP_z[vi] * src1[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp186;
fp186 = inteval->PA_z[vi] * src0[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp184;
fp184 = fp186 + fp185;
LIBINT2_REALTYPE fp181;
fp181 = fp184 + fp182;
target[((hsi*60+28)*1+lsi)*1] = fp181;
LIBINT2_REALTYPE fp188;
fp188 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp190;
fp190 = inteval->WP_z[vi] * src1[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp191;
fp191 = inteval->PA_z[vi] * src0[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp189;
fp189 = fp191 + fp190;
LIBINT2_REALTYPE fp187;
fp187 = fp189 + fp188;
target[((hsi*60+27)*1+lsi)*1] = fp187;
LIBINT2_REALTYPE fp193;
fp193 = inteval->WP_z[vi] * src1[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp194;
fp194 = inteval->PA_z[vi] * src0[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp192;
fp192 = fp194 + fp193;
target[((hsi*60+26)*1+lsi)*1] = fp192;
LIBINT2_REALTYPE fp197;
fp197 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp196;
fp196 = fp197 * src4[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp199;
fp199 = inteval->WP_z[vi] * src1[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp200;
fp200 = inteval->PA_z[vi] * src0[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp198;
fp198 = fp200 + fp199;
LIBINT2_REALTYPE fp195;
fp195 = fp198 + fp196;
target[((hsi*60+25)*1+lsi)*1] = fp195;
LIBINT2_REALTYPE fp202;
fp202 = inteval->oo2ze[vi] * src4[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp204;
fp204 = inteval->WP_z[vi] * src1[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp205;
fp205 = inteval->PA_z[vi] * src0[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp203;
fp203 = fp205 + fp204;
LIBINT2_REALTYPE fp201;
fp201 = fp203 + fp202;
target[((hsi*60+24)*1+lsi)*1] = fp201;
LIBINT2_REALTYPE fp207;
fp207 = inteval->WP_z[vi] * src1[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp208;
fp208 = inteval->PA_z[vi] * src0[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp206;
fp206 = fp208 + fp207;
target[((hsi*60+23)*1+lsi)*1] = fp206;
LIBINT2_REALTYPE fp210;
fp210 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp212;
fp212 = inteval->WP_z[vi] * src1[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp213;
fp213 = inteval->PA_z[vi] * src0[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp211;
fp211 = fp213 + fp212;
LIBINT2_REALTYPE fp209;
fp209 = fp211 + fp210;
target[((hsi*60+22)*1+lsi)*1] = fp209;
LIBINT2_REALTYPE fp215;
fp215 = inteval->WP_z[vi] * src1[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp216;
fp216 = inteval->PA_z[vi] * src0[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp214;
fp214 = fp216 + fp215;
target[((hsi*60+21)*1+lsi)*1] = fp214;
LIBINT2_REALTYPE fp218;
fp218 = inteval->WP_z[vi] * src1[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp219;
fp219 = inteval->PA_z[vi] * src0[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp217;
fp217 = fp219 + fp218;
target[((hsi*60+20)*1+lsi)*1] = fp217;
LIBINT2_REALTYPE fp221;
fp221 = inteval->WP_y[vi] * src1[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp222;
fp222 = inteval->PA_y[vi] * src0[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp220;
fp220 = fp222 + fp221;
target[((hsi*60+19)*1+lsi)*1] = fp220;
LIBINT2_REALTYPE fp224;
fp224 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp226;
fp226 = inteval->WP_y[vi] * src1[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp227;
fp227 = inteval->PA_y[vi] * src0[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp225;
fp225 = fp227 + fp226;
LIBINT2_REALTYPE fp223;
fp223 = fp225 + fp224;
target[((hsi*60+18)*1+lsi)*1] = fp223;
LIBINT2_REALTYPE fp230;
fp230 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp229;
fp229 = fp230 * src4[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp232;
fp232 = inteval->WP_y[vi] * src1[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp233;
fp233 = inteval->PA_y[vi] * src0[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp231;
fp231 = fp233 + fp232;
LIBINT2_REALTYPE fp228;
fp228 = fp231 + fp229;
target[((hsi*60+17)*1+lsi)*1] = fp228;
LIBINT2_REALTYPE fp236;
fp236 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp235;
fp235 = fp236 * src4[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp238;
fp238 = inteval->WP_y[vi] * src1[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp239;
fp239 = inteval->PA_y[vi] * src0[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp237;
fp237 = fp239 + fp238;
LIBINT2_REALTYPE fp234;
fp234 = fp237 + fp235;
target[((hsi*60+16)*1+lsi)*1] = fp234;
LIBINT2_REALTYPE fp241;
fp241 = inteval->WP_y[vi] * src1[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp242;
fp242 = inteval->PA_y[vi] * src0[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp240;
fp240 = fp242 + fp241;
target[((hsi*60+15)*1+lsi)*1] = fp240;
LIBINT2_REALTYPE fp244;
fp244 = inteval->oo2ze[vi] * src4[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp246;
fp246 = inteval->WP_y[vi] * src1[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp247;
fp247 = inteval->PA_y[vi] * src0[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp245;
fp245 = fp247 + fp246;
LIBINT2_REALTYPE fp243;
fp243 = fp245 + fp244;
target[((hsi*60+14)*1+lsi)*1] = fp243;
LIBINT2_REALTYPE fp250;
fp250 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp249;
fp249 = fp250 * src4[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp252;
fp252 = inteval->WP_y[vi] * src1[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp253;
fp253 = inteval->PA_y[vi] * src0[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp251;
fp251 = fp253 + fp252;
LIBINT2_REALTYPE fp248;
fp248 = fp251 + fp249;
target[((hsi*60+13)*1+lsi)*1] = fp248;
LIBINT2_REALTYPE fp255;
fp255 = inteval->WP_y[vi] * src1[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp256;
fp256 = inteval->PA_y[vi] * src0[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp254;
fp254 = fp256 + fp255;
target[((hsi*60+12)*1+lsi)*1] = fp254;
LIBINT2_REALTYPE fp258;
fp258 = inteval->oo2ze[vi] * src4[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp260;
fp260 = inteval->WP_y[vi] * src1[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp261;
fp261 = inteval->PA_y[vi] * src0[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp259;
fp259 = fp261 + fp260;
LIBINT2_REALTYPE fp257;
fp257 = fp259 + fp258;
target[((hsi*60+11)*1+lsi)*1] = fp257;
LIBINT2_REALTYPE fp263;
fp263 = inteval->WP_y[vi] * src1[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp264;
fp264 = inteval->PA_y[vi] * src0[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp262;
fp262 = fp264 + fp263;
target[((hsi*60+10)*1+lsi)*1] = fp262;
LIBINT2_REALTYPE fp268;
fp268 = inteval->roz[vi] * src3[((hsi*10+9)*1+lsi)*1];
LIBINT2_REALTYPE fp267;
fp267 = src2[((hsi*10+9)*1+lsi)*1] - fp268;
LIBINT2_REALTYPE fp266;
fp266 = inteval->oo2z[vi] * fp267;
LIBINT2_REALTYPE fp270;
fp270 = inteval->WP_x[vi] * src1[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp271;
fp271 = inteval->PA_x[vi] * src0[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp269;
fp269 = fp271 + fp270;
LIBINT2_REALTYPE fp265;
fp265 = fp269 + fp266;
target[((hsi*60+9)*1+lsi)*1] = fp265;
LIBINT2_REALTYPE fp275;
fp275 = inteval->roz[vi] * src3[((hsi*10+8)*1+lsi)*1];
LIBINT2_REALTYPE fp274;
fp274 = src2[((hsi*10+8)*1+lsi)*1] - fp275;
LIBINT2_REALTYPE fp273;
fp273 = inteval->oo2z[vi] * fp274;
LIBINT2_REALTYPE fp277;
fp277 = inteval->WP_x[vi] * src1[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp278;
fp278 = inteval->PA_x[vi] * src0[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp276;
fp276 = fp278 + fp277;
LIBINT2_REALTYPE fp272;
fp272 = fp276 + fp273;
target[((hsi*60+8)*1+lsi)*1] = fp272;
LIBINT2_REALTYPE fp282;
fp282 = inteval->roz[vi] * src3[((hsi*10+7)*1+lsi)*1];
LIBINT2_REALTYPE fp281;
fp281 = src2[((hsi*10+7)*1+lsi)*1] - fp282;
LIBINT2_REALTYPE fp280;
fp280 = inteval->oo2z[vi] * fp281;
LIBINT2_REALTYPE fp284;
fp284 = inteval->WP_x[vi] * src1[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp285;
fp285 = inteval->PA_x[vi] * src0[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp283;
fp283 = fp285 + fp284;
LIBINT2_REALTYPE fp279;
fp279 = fp283 + fp280;
target[((hsi*60+7)*1+lsi)*1] = fp279;
LIBINT2_REALTYPE fp289;
fp289 = inteval->roz[vi] * src3[((hsi*10+6)*1+lsi)*1];
LIBINT2_REALTYPE fp288;
fp288 = src2[((hsi*10+6)*1+lsi)*1] - fp289;
LIBINT2_REALTYPE fp287;
fp287 = inteval->oo2z[vi] * fp288;
LIBINT2_REALTYPE fp291;
fp291 = inteval->WP_x[vi] * src1[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp292;
fp292 = inteval->PA_x[vi] * src0[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp290;
fp290 = fp292 + fp291;
LIBINT2_REALTYPE fp286;
fp286 = fp290 + fp287;
target[((hsi*60+6)*1+lsi)*1] = fp286;
LIBINT2_REALTYPE fp294;
fp294 = inteval->oo2ze[vi] * src4[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp298;
fp298 = inteval->roz[vi] * src3[((hsi*10+5)*1+lsi)*1];
LIBINT2_REALTYPE fp297;
fp297 = src2[((hsi*10+5)*1+lsi)*1] - fp298;
LIBINT2_REALTYPE fp296;
fp296 = inteval->oo2z[vi] * fp297;
LIBINT2_REALTYPE fp300;
fp300 = inteval->WP_x[vi] * src1[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp301;
fp301 = inteval->PA_x[vi] * src0[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp299;
fp299 = fp301 + fp300;
LIBINT2_REALTYPE fp295;
fp295 = fp299 + fp296;
LIBINT2_REALTYPE fp293;
fp293 = fp295 + fp294;
target[((hsi*60+5)*1+lsi)*1] = fp293;
LIBINT2_REALTYPE fp303;
fp303 = inteval->oo2ze[vi] * src4[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp307;
fp307 = inteval->roz[vi] * src3[((hsi*10+4)*1+lsi)*1];
LIBINT2_REALTYPE fp306;
fp306 = src2[((hsi*10+4)*1+lsi)*1] - fp307;
LIBINT2_REALTYPE fp305;
fp305 = inteval->oo2z[vi] * fp306;
LIBINT2_REALTYPE fp309;
fp309 = inteval->WP_x[vi] * src1[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp310;
fp310 = inteval->PA_x[vi] * src0[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp308;
fp308 = fp310 + fp309;
LIBINT2_REALTYPE fp304;
fp304 = fp308 + fp305;
LIBINT2_REALTYPE fp302;
fp302 = fp304 + fp303;
target[((hsi*60+4)*1+lsi)*1] = fp302;
LIBINT2_REALTYPE fp312;
fp312 = inteval->oo2ze[vi] * src4[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp316;
fp316 = inteval->roz[vi] * src3[((hsi*10+3)*1+lsi)*1];
LIBINT2_REALTYPE fp315;
fp315 = src2[((hsi*10+3)*1+lsi)*1] - fp316;
LIBINT2_REALTYPE fp314;
fp314 = inteval->oo2z[vi] * fp315;
LIBINT2_REALTYPE fp318;
fp318 = inteval->WP_x[vi] * src1[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp319;
fp319 = inteval->PA_x[vi] * src0[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp317;
fp317 = fp319 + fp318;
LIBINT2_REALTYPE fp313;
fp313 = fp317 + fp314;
LIBINT2_REALTYPE fp311;
fp311 = fp313 + fp312;
target[((hsi*60+3)*1+lsi)*1] = fp311;
LIBINT2_REALTYPE fp322;
fp322 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp321;
fp321 = fp322 * src4[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp326;
fp326 = inteval->roz[vi] * src3[((hsi*10+2)*1+lsi)*1];
LIBINT2_REALTYPE fp325;
fp325 = src2[((hsi*10+2)*1+lsi)*1] - fp326;
LIBINT2_REALTYPE fp324;
fp324 = inteval->oo2z[vi] * fp325;
LIBINT2_REALTYPE fp328;
fp328 = inteval->WP_x[vi] * src1[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp329;
fp329 = inteval->PA_x[vi] * src0[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp327;
fp327 = fp329 + fp328;
LIBINT2_REALTYPE fp323;
fp323 = fp327 + fp324;
LIBINT2_REALTYPE fp320;
fp320 = fp323 + fp321;
target[((hsi*60+2)*1+lsi)*1] = fp320;
LIBINT2_REALTYPE fp332;
fp332 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp331;
fp331 = fp332 * src4[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp336;
fp336 = inteval->roz[vi] * src3[((hsi*10+1)*1+lsi)*1];
LIBINT2_REALTYPE fp335;
fp335 = src2[((hsi*10+1)*1+lsi)*1] - fp336;
LIBINT2_REALTYPE fp334;
fp334 = inteval->oo2z[vi] * fp335;
LIBINT2_REALTYPE fp338;
fp338 = inteval->WP_x[vi] * src1[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp339;
fp339 = inteval->PA_x[vi] * src0[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp337;
fp337 = fp339 + fp338;
LIBINT2_REALTYPE fp333;
fp333 = fp337 + fp334;
LIBINT2_REALTYPE fp330;
fp330 = fp333 + fp331;
target[((hsi*60+1)*1+lsi)*1] = fp330;
LIBINT2_REALTYPE fp342;
fp342 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp341;
fp341 = fp342 * src4[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp346;
fp346 = inteval->roz[vi] * src3[((hsi*10+0)*1+lsi)*1];
LIBINT2_REALTYPE fp345;
fp345 = src2[((hsi*10+0)*1+lsi)*1] - fp346;
LIBINT2_REALTYPE fp344;
fp344 = inteval->oo2z[vi] * fp345;
LIBINT2_REALTYPE fp348;
fp348 = inteval->WP_x[vi] * src1[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp349;
fp349 = inteval->PA_x[vi] * src0[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp347;
fp347 = fp349 + fp348;
LIBINT2_REALTYPE fp343;
fp343 = fp347 + fp344;
LIBINT2_REALTYPE fp340;
fp340 = fp343 + fp341;
target[((hsi*60+0)*1+lsi)*1] = fp340;
LIBINT2_REALTYPE fp2;
fp2 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp1;
fp1 = fp2 * src4[((hsi*18+17)*1+lsi)*1];
LIBINT2_REALTYPE fp4;
fp4 = inteval->oo2z[vi] * fp267;
LIBINT2_REALTYPE fp6;
fp6 = inteval->WP_z[vi] * src1[((hsi*30+29)*1+lsi)*1];
LIBINT2_REALTYPE fp7;
fp7 = inteval->PA_z[vi] * src0[((hsi*30+29)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = fp7 + fp6;
LIBINT2_REALTYPE fp3;
fp3 = fp5 + fp4;
LIBINT2_REALTYPE fp0;
fp0 = fp3 + fp1;
target[((hsi*60+59)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp10;
fp10 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp9;
fp9 = fp10 * src4[((hsi*18+16)*1+lsi)*1];
LIBINT2_REALTYPE fp12;
fp12 = inteval->oo2z[vi] * fp274;
LIBINT2_REALTYPE fp14;
fp14 = inteval->WP_z[vi] * src1[((hsi*30+28)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = inteval->PA_z[vi] * src0[((hsi*30+28)*1+lsi)*1];
LIBINT2_REALTYPE fp13;
fp13 = fp15 + fp14;
LIBINT2_REALTYPE fp11;
fp11 = fp13 + fp12;
LIBINT2_REALTYPE fp8;
fp8 = fp11 + fp9;
target[((hsi*60+58)*1+lsi)*1] = fp8;
LIBINT2_REALTYPE fp17;
fp17 = inteval->oo2ze[vi] * src4[((hsi*18+15)*1+lsi)*1];
LIBINT2_REALTYPE fp19;
fp19 = inteval->oo2z[vi] * fp281;
LIBINT2_REALTYPE fp21;
fp21 = inteval->WP_z[vi] * src1[((hsi*30+27)*1+lsi)*1];
LIBINT2_REALTYPE fp22;
fp22 = inteval->PA_z[vi] * src0[((hsi*30+27)*1+lsi)*1];
LIBINT2_REALTYPE fp20;
fp20 = fp22 + fp21;
LIBINT2_REALTYPE fp18;
fp18 = fp20 + fp19;
LIBINT2_REALTYPE fp16;
fp16 = fp18 + fp17;
target[((hsi*60+57)*1+lsi)*1] = fp16;
LIBINT2_REALTYPE fp24;
fp24 = inteval->oo2z[vi] * fp288;
LIBINT2_REALTYPE fp26;
fp26 = inteval->WP_z[vi] * src1[((hsi*30+26)*1+lsi)*1];
LIBINT2_REALTYPE fp27;
fp27 = inteval->PA_z[vi] * src0[((hsi*30+26)*1+lsi)*1];
LIBINT2_REALTYPE fp25;
fp25 = fp27 + fp26;
LIBINT2_REALTYPE fp23;
fp23 = fp25 + fp24;
target[((hsi*60+56)*1+lsi)*1] = fp23;
LIBINT2_REALTYPE fp30;
fp30 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp29;
fp29 = fp30 * src4[((hsi*18+14)*1+lsi)*1];
LIBINT2_REALTYPE fp32;
fp32 = inteval->oo2z[vi] * fp297;
LIBINT2_REALTYPE fp34;
fp34 = inteval->WP_z[vi] * src1[((hsi*30+25)*1+lsi)*1];
LIBINT2_REALTYPE fp35;
fp35 = inteval->PA_z[vi] * src0[((hsi*30+25)*1+lsi)*1];
LIBINT2_REALTYPE fp33;
fp33 = fp35 + fp34;
LIBINT2_REALTYPE fp31;
fp31 = fp33 + fp32;
LIBINT2_REALTYPE fp28;
fp28 = fp31 + fp29;
target[((hsi*60+55)*1+lsi)*1] = fp28;
LIBINT2_REALTYPE fp37;
fp37 = inteval->oo2ze[vi] * src4[((hsi*18+13)*1+lsi)*1];
LIBINT2_REALTYPE fp39;
fp39 = inteval->oo2z[vi] * fp306;
LIBINT2_REALTYPE fp41;
fp41 = inteval->WP_z[vi] * src1[((hsi*30+24)*1+lsi)*1];
LIBINT2_REALTYPE fp42;
fp42 = inteval->PA_z[vi] * src0[((hsi*30+24)*1+lsi)*1];
LIBINT2_REALTYPE fp40;
fp40 = fp42 + fp41;
LIBINT2_REALTYPE fp38;
fp38 = fp40 + fp39;
LIBINT2_REALTYPE fp36;
fp36 = fp38 + fp37;
target[((hsi*60+54)*1+lsi)*1] = fp36;
LIBINT2_REALTYPE fp44;
fp44 = inteval->oo2z[vi] * fp315;
LIBINT2_REALTYPE fp46;
fp46 = inteval->WP_z[vi] * src1[((hsi*30+23)*1+lsi)*1];
LIBINT2_REALTYPE fp47;
fp47 = inteval->PA_z[vi] * src0[((hsi*30+23)*1+lsi)*1];
LIBINT2_REALTYPE fp45;
fp45 = fp47 + fp46;
LIBINT2_REALTYPE fp43;
fp43 = fp45 + fp44;
target[((hsi*60+53)*1+lsi)*1] = fp43;
LIBINT2_REALTYPE fp49;
fp49 = inteval->oo2ze[vi] * src4[((hsi*18+12)*1+lsi)*1];
LIBINT2_REALTYPE fp51;
fp51 = inteval->oo2z[vi] * fp325;
LIBINT2_REALTYPE fp53;
fp53 = inteval->WP_z[vi] * src1[((hsi*30+22)*1+lsi)*1];
LIBINT2_REALTYPE fp54;
fp54 = inteval->PA_z[vi] * src0[((hsi*30+22)*1+lsi)*1];
LIBINT2_REALTYPE fp52;
fp52 = fp54 + fp53;
LIBINT2_REALTYPE fp50;
fp50 = fp52 + fp51;
LIBINT2_REALTYPE fp48;
fp48 = fp50 + fp49;
target[((hsi*60+52)*1+lsi)*1] = fp48;
LIBINT2_REALTYPE fp56;
fp56 = inteval->oo2z[vi] * fp335;
LIBINT2_REALTYPE fp58;
fp58 = inteval->WP_z[vi] * src1[((hsi*30+21)*1+lsi)*1];
LIBINT2_REALTYPE fp59;
fp59 = inteval->PA_z[vi] * src0[((hsi*30+21)*1+lsi)*1];
LIBINT2_REALTYPE fp57;
fp57 = fp59 + fp58;
LIBINT2_REALTYPE fp55;
fp55 = fp57 + fp56;
target[((hsi*60+51)*1+lsi)*1] = fp55;
LIBINT2_REALTYPE fp61;
fp61 = inteval->oo2z[vi] * fp345;
LIBINT2_REALTYPE fp63;
fp63 = inteval->WP_z[vi] * src1[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp64;
fp64 = inteval->PA_z[vi] * src0[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp62;
fp62 = fp64 + fp63;
LIBINT2_REALTYPE fp60;
fp60 = fp62 + fp61;
target[((hsi*60+50)*1+lsi)*1] = fp60;
LIBINT2_REALTYPE fp67;
fp67 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp66;
fp66 = fp67 * src4[((hsi*18+11)*1+lsi)*1];
LIBINT2_REALTYPE fp69;
fp69 = inteval->WP_z[vi] * src1[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp70;
fp70 = inteval->PA_z[vi] * src0[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp68;
fp68 = fp70 + fp69;
LIBINT2_REALTYPE fp65;
fp65 = fp68 + fp66;
target[((hsi*60+49)*1+lsi)*1] = fp65;
LIBINT2_REALTYPE fp73;
fp73 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp72;
fp72 = fp73 * src4[((hsi*18+10)*1+lsi)*1];
LIBINT2_REALTYPE fp75;
fp75 = inteval->WP_z[vi] * src1[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp76;
fp76 = inteval->PA_z[vi] * src0[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp74;
fp74 = fp76 + fp75;
LIBINT2_REALTYPE fp71;
fp71 = fp74 + fp72;
target[((hsi*60+48)*1+lsi)*1] = fp71;
LIBINT2_REALTYPE fp78;
fp78 = inteval->oo2ze[vi] * src4[((hsi*18+9)*1+lsi)*1];
LIBINT2_REALTYPE fp80;
fp80 = inteval->WP_z[vi] * src1[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp81;
fp81 = inteval->PA_z[vi] * src0[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp79;
fp79 = fp81 + fp80;
LIBINT2_REALTYPE fp77;
fp77 = fp79 + fp78;
target[((hsi*60+47)*1+lsi)*1] = fp77;
LIBINT2_REALTYPE fp83;
fp83 = inteval->WP_z[vi] * src1[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp84;
fp84 = inteval->PA_z[vi] * src0[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp82;
fp82 = fp84 + fp83;
target[((hsi*60+46)*1+lsi)*1] = fp82;
LIBINT2_REALTYPE fp87;
fp87 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp86;
fp86 = fp87 * src4[((hsi*18+8)*1+lsi)*1];
LIBINT2_REALTYPE fp89;
fp89 = inteval->WP_z[vi] * src1[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp90;
fp90 = inteval->PA_z[vi] * src0[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp88;
fp88 = fp90 + fp89;
LIBINT2_REALTYPE fp85;
fp85 = fp88 + fp86;
target[((hsi*60+45)*1+lsi)*1] = fp85;
LIBINT2_REALTYPE fp92;
fp92 = inteval->oo2ze[vi] * src4[((hsi*18+7)*1+lsi)*1];
LIBINT2_REALTYPE fp94;
fp94 = inteval->WP_z[vi] * src1[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp95;
fp95 = inteval->PA_z[vi] * src0[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp93;
fp93 = fp95 + fp94;
LIBINT2_REALTYPE fp91;
fp91 = fp93 + fp92;
target[((hsi*60+44)*1+lsi)*1] = fp91;
LIBINT2_REALTYPE fp97;
fp97 = inteval->WP_z[vi] * src1[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp98;
fp98 = inteval->PA_z[vi] * src0[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp96;
fp96 = fp98 + fp97;
target[((hsi*60+43)*1+lsi)*1] = fp96;
LIBINT2_REALTYPE fp100;
fp100 = inteval->oo2ze[vi] * src4[((hsi*18+6)*1+lsi)*1];
LIBINT2_REALTYPE fp102;
fp102 = inteval->WP_z[vi] * src1[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = inteval->PA_z[vi] * src0[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp101;
fp101 = fp103 + fp102;
LIBINT2_REALTYPE fp99;
fp99 = fp101 + fp100;
target[((hsi*60+42)*1+lsi)*1] = fp99;
LIBINT2_REALTYPE fp105;
fp105 = inteval->WP_z[vi] * src1[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp106;
fp106 = inteval->PA_z[vi] * src0[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp104;
fp104 = fp106 + fp105;
target[((hsi*60+41)*1+lsi)*1] = fp104;
LIBINT2_REALTYPE fp108;
fp108 = inteval->WP_z[vi] * src1[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp109;
fp109 = inteval->PA_z[vi] * src0[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp107;
fp107 = fp109 + fp108;
target[((hsi*60+40)*1+lsi)*1] = fp107;
LIBINT2_REALTYPE fp111;
fp111 = inteval->oo2z[vi] * fp267;
LIBINT2_REALTYPE fp113;
fp113 = inteval->WP_y[vi] * src1[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp114;
fp114 = inteval->PA_y[vi] * src0[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp112;
fp112 = fp114 + fp113;
LIBINT2_REALTYPE fp110;
fp110 = fp112 + fp111;
target[((hsi*60+39)*1+lsi)*1] = fp110;
LIBINT2_REALTYPE fp116;
fp116 = inteval->oo2ze[vi] * src4[((hsi*18+11)*1+lsi)*1];
LIBINT2_REALTYPE fp118;
fp118 = inteval->oo2z[vi] * fp274;
LIBINT2_REALTYPE fp120;
fp120 = inteval->WP_y[vi] * src1[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp121;
fp121 = inteval->PA_y[vi] * src0[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp119;
fp119 = fp121 + fp120;
LIBINT2_REALTYPE fp117;
fp117 = fp119 + fp118;
LIBINT2_REALTYPE fp115;
fp115 = fp117 + fp116;
target[((hsi*60+38)*1+lsi)*1] = fp115;
LIBINT2_REALTYPE fp124;
fp124 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp123;
fp123 = fp124 * src4[((hsi*18+10)*1+lsi)*1];
LIBINT2_REALTYPE fp126;
fp126 = inteval->oo2z[vi] * fp281;
LIBINT2_REALTYPE fp128;
fp128 = inteval->WP_y[vi] * src1[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp129;
fp129 = inteval->PA_y[vi] * src0[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp127;
fp127 = fp129 + fp128;
LIBINT2_REALTYPE fp125;
fp125 = fp127 + fp126;
LIBINT2_REALTYPE fp122;
fp122 = fp125 + fp123;
target[((hsi*60+37)*1+lsi)*1] = fp122;
LIBINT2_REALTYPE fp132;
fp132 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp131;
fp131 = fp132 * src4[((hsi*18+9)*1+lsi)*1];
LIBINT2_REALTYPE fp134;
fp134 = inteval->oo2z[vi] * fp288;
LIBINT2_REALTYPE fp136;
fp136 = inteval->WP_y[vi] * src1[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp137;
fp137 = inteval->PA_y[vi] * src0[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp135;
fp135 = fp137 + fp136;
LIBINT2_REALTYPE fp133;
fp133 = fp135 + fp134;
LIBINT2_REALTYPE fp130;
fp130 = fp133 + fp131;
target[((hsi*60+36)*1+lsi)*1] = fp130;
LIBINT2_REALTYPE fp139;
fp139 = inteval->oo2z[vi] * fp297;
LIBINT2_REALTYPE fp141;
fp141 = inteval->WP_y[vi] * src1[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp142;
fp142 = inteval->PA_y[vi] * src0[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp140;
fp140 = fp142 + fp141;
LIBINT2_REALTYPE fp138;
fp138 = fp140 + fp139;
target[((hsi*60+35)*1+lsi)*1] = fp138;
LIBINT2_REALTYPE fp144;
fp144 = inteval->oo2ze[vi] * src4[((hsi*18+8)*1+lsi)*1];
LIBINT2_REALTYPE fp146;
fp146 = inteval->oo2z[vi] * fp306;
LIBINT2_REALTYPE fp148;
fp148 = inteval->WP_y[vi] * src1[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp149;
fp149 = inteval->PA_y[vi] * src0[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp147;
fp147 = fp149 + fp148;
LIBINT2_REALTYPE fp145;
fp145 = fp147 + fp146;
LIBINT2_REALTYPE fp143;
fp143 = fp145 + fp144;
target[((hsi*60+34)*1+lsi)*1] = fp143;
LIBINT2_REALTYPE fp152;
fp152 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp151;
fp151 = fp152 * src4[((hsi*18+7)*1+lsi)*1];
LIBINT2_REALTYPE fp154;
fp154 = inteval->oo2z[vi] * fp315;
LIBINT2_REALTYPE fp156;
fp156 = inteval->WP_y[vi] * src1[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp157;
fp157 = inteval->PA_y[vi] * src0[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp155;
fp155 = fp157 + fp156;
LIBINT2_REALTYPE fp153;
fp153 = fp155 + fp154;
LIBINT2_REALTYPE fp150;
fp150 = fp153 + fp151;
target[((hsi*60+33)*1+lsi)*1] = fp150;
LIBINT2_REALTYPE fp159;
fp159 = inteval->oo2z[vi] * fp325;
LIBINT2_REALTYPE fp161;
fp161 = inteval->WP_y[vi] * src1[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp162;
fp162 = inteval->PA_y[vi] * src0[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp160;
fp160 = fp162 + fp161;
LIBINT2_REALTYPE fp158;
fp158 = fp160 + fp159;
target[((hsi*60+32)*1+lsi)*1] = fp158;
LIBINT2_REALTYPE fp164;
fp164 = inteval->oo2ze[vi] * src4[((hsi*18+6)*1+lsi)*1];
LIBINT2_REALTYPE fp166;
fp166 = inteval->oo2z[vi] * fp335;
LIBINT2_REALTYPE fp168;
fp168 = inteval->WP_y[vi] * src1[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp169;
fp169 = inteval->PA_y[vi] * src0[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp167;
fp167 = fp169 + fp168;
LIBINT2_REALTYPE fp165;
fp165 = fp167 + fp166;
LIBINT2_REALTYPE fp163;
fp163 = fp165 + fp164;
target[((hsi*60+31)*1+lsi)*1] = fp163;
LIBINT2_REALTYPE fp171;
fp171 = inteval->oo2z[vi] * fp345;
LIBINT2_REALTYPE fp173;
fp173 = inteval->WP_y[vi] * src1[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp174;
fp174 = inteval->PA_y[vi] * src0[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp172;
fp172 = fp174 + fp173;
LIBINT2_REALTYPE fp170;
fp170 = fp172 + fp171;
target[((hsi*60+30)*1+lsi)*1] = fp170;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 350 */
}

#ifdef __cplusplus
};
#endif
